==> haskell-barbies-2.1.1.0-92.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-barbies.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 barbies
version:              2.1.1.0
visibility:           public
id:                   barbies-2.1.1.0-3T0kdIDAaxgGfXXLZEgu6e
key:                  barbies-2.1.1.0-3T0kdIDAaxgGfXXLZEgu6e
license:              BSD-3-Clause
copyright:            2018 Daniel Gorin
maintainer:           jcpetruzza@gmail.com
author:               Daniel Gorin
homepage:             https://github.com/jcpetruzza/barbies#readme
synopsis:             Classes for working with types that can change clothes.
description:
    Types that are parametric on a functor are like Barbies that have an outfit for each role. This package provides the basic abstractions to work with them comfortably.

category:             Data Structures
abi:                  72d7dc18203ba93826f1aa3355868cb0
exposed:              True
exposed-modules:
    Barbies Barbies.Bare Barbies.Bi Barbies.Constraints
    Barbies.Internal Data.Functor.Barbie Data.Functor.Transformer

hidden-modules:
    Barbies.Generics.Applicative Barbies.Generics.Bare
    Barbies.Generics.Constraints Barbies.Generics.Distributive
    Barbies.Generics.Functor Barbies.Generics.Traversable
    Barbies.Internal.ApplicativeB Barbies.Internal.ApplicativeT
    Barbies.Internal.BareB Barbies.Internal.ConstraintsB
    Barbies.Internal.ConstraintsT Barbies.Internal.Containers
    Barbies.Internal.Dicts Barbies.Internal.DistributiveB
    Barbies.Internal.DistributiveT Barbies.Internal.FunctorB
    Barbies.Internal.FunctorT Barbies.Internal.MonadT
    Barbies.Internal.TraversableB Barbies.Internal.TraversableT
    Barbies.Internal.Trivial Barbies.Internal.Wear
    Barbies.Internal.Wrappers Barbies.Internal.Writer
    Data.Generics.GenericN

import-dirs:          /usr/lib/ghc-9.4.8/site-local/barbies-2.1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/barbies-2.1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/barbies-2.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-barbies
hs-libraries:         HSbarbies-2.1.1.0-3T0kdIDAaxgGfXXLZEgu6e
depends:
    base-4.17.2.1 distributive-0.6.2.1-3469zRFAXaLLtl1TZCSnJt
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-barbies/html/barbies.haddock
haddock-html:         /usr/share/doc/haskell-barbies/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-barbies-2.1.1.0-108.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-barbies.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 barbies
version:              2.1.1.0
visibility:           public
id:                   barbies-2.1.1.0-1MHGlcEngKuIrvZXTPfFwF
key:                  barbies-2.1.1.0-1MHGlcEngKuIrvZXTPfFwF
license:              BSD-3-Clause
copyright:            2018 Daniel Gorin
maintainer:           jcpetruzza@gmail.com
author:               Daniel Gorin
homepage:             https://github.com/jcpetruzza/barbies#readme
synopsis:             Classes for working with types that can change clothes.
description:
    Types that are parametric on a functor are like Barbies that have an outfit for each role. This package provides the basic abstractions to work with them comfortably.

category:             Data Structures
abi:                  61c29b6cf5e7f80e38d4b1d768b4dd4c
exposed:              True
exposed-modules:
    Barbies Barbies.Bare Barbies.Bi Barbies.Constraints
    Barbies.Internal Data.Functor.Barbie Data.Functor.Transformer

hidden-modules:
    Barbies.Generics.Applicative Barbies.Generics.Bare
    Barbies.Generics.Constraints Barbies.Generics.Distributive
    Barbies.Generics.Functor Barbies.Generics.Traversable
    Barbies.Internal.ApplicativeB Barbies.Internal.ApplicativeT
    Barbies.Internal.BareB Barbies.Internal.ConstraintsB
    Barbies.Internal.ConstraintsT Barbies.Internal.Containers
    Barbies.Internal.Dicts Barbies.Internal.DistributiveB
    Barbies.Internal.DistributiveT Barbies.Internal.FunctorB
    Barbies.Internal.FunctorT Barbies.Internal.MonadT
    Barbies.Internal.TraversableB Barbies.Internal.TraversableT
    Barbies.Internal.Trivial Barbies.Internal.Wear
    Barbies.Internal.Wrappers Barbies.Internal.Writer
    Data.Generics.GenericN

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/barbies-2.1.1.0
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/barbies-2.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/barbies-2.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-barbies
hs-libraries:         HSbarbies-2.1.1.0-1MHGlcEngKuIrvZXTPfFwF
depends:
    base-4.18.3.0 distributive-0.6.2.1-CDdZRmivT2xBsLLFkKqpbb
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-barbies/html/barbies.haddock
haddock-html:         /usr/share/doc/haskell-barbies/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
